import { ColorShifting } from './models';

export type ColorSet = {
  root: string;
  hover: string;
  active: string;
  focus: string;
  disabled: string;
  onRoot: string;
  onHover: string;
  onActive: string;
  onFocus: string;
  onDisabled: string;
};

export type Baseline = {
  primary: ColorSet;
  secondary: ColorSet | null;
  tertiary: ColorSet | null;
  accent: ColorSet | null;
  neutral: ColorSet;
  danger: ColorSet;
  success: ColorSet;
  warning: ColorSet;
  info: ColorSet;
  outline: ColorSet;
  foreground: ColorSet;
  background: ColorSet;
};

export type QScheme = {
  light: Baseline;
  dark: Baseline;
};

export type QSchemeSetting = {
  hover: ColorShifting;
  acitve: ColorShifting;
  focus: ColorShifting;
  disabled: ColorShifting;
  dark_convert: ColorShifting;
  expand_method: string;
  wacg_follows: string;
};

export type QSchemeSource = {
  primary: string;
  secondary: string | null;
  tertiary: string | null;
  accent: string | null;
  danger: string;
  success: string;
  warning: string;
  info: string;
  foreground: string;
  background: string;
  setting: QSchemeSetting;
};

export type QSchemeStorage = {
  source: QSchemeSource;
  scheme: QScheme;
};
